intelmq.bots.outputs.blackhole package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.blackhole package

## Submodules

## intelmq.bots.outputs.blackhole.output module

`intelmq.bots.outputs.blackhole.output.` `BOT`

  alias of `intelmq.bots.outputs.blackhole.output.BlackholeOutputBot`

class `intelmq.bots.outputs.blackhole.output.` `BlackholeOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `process`()

## Module contents